@@ -80,7 +80,6 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
             use std::env;
             use tokio::task;
-            use tokio::time::interval;
             use checkout_core::cloud_pubsub;
             use checkout_core::dropshot;
             use checkout_core::dropshot::endpoint;
@@ -144,10 +143,8 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             ) {
                 task::spawn(async move {
                     let subscription = internal_ctx.payment_processing_subscription.clone();
-                    let mut intv = interval(Duration::from_secs(5));
 
-                    loop {
-                        intv.tick().await;
+                    while subscription.client().is_running() {
                         println!("pulling payment processing messages");
 
                         match subscription.get_messages::<Message>().await {
